#-----------------------------------------------------------------------------
%{?!dist:	%define	dist	.ok}
#-----------------------------------------------------------------------------
Name		:	openvpn
Version		:	2.6.12
Release		:	17.2.33.rel%{?dist}
Summary		:	A Secure tunneling daemon
Group		:	Applications/Internet

Packager	:	Osukiss Project	<build-ok@osukiss.org>

License		:	GPLv2+
URL		:	https://openvpn.net/community-downloads/
			#https://github.com/OpenVPN/openvpn

Source0		:	%{name}-%{version}.tar.gz
Source1		:	%{name}-ok_addon.tar.gz

#-----------------------------------------------------------------------------
BuildRequires	:	autoconf
BuildRequires	:	autoconf-archive
BuildRequires	:	automake
BuildRequires	:	gnupg
BuildRequires	:	gcc
BuildRequires	:	gettext
BuildRequires	:	iproute-devel
BuildRequires	:	libtool
BuildRequires	:	libcap-ng-devel
BuildRequires	:	lz4-devel
BuildRequires	:	lzo-devel
BuildRequires	:	openssl-devel
BuildRequires	:	python3-docutils


Requires	:	bc
Requires	:	chkconfig
Requires	:	iproute
Requires	:	logrotate
Requires	:	lz4
Requires	:	psmisc
Requires	:	shadow

#-----------------------------------------------------------------------------
%description
OpenVPN is a robust and highly flexible VPN daemon. OpenVPN
supports SSL/TLS security, ethernet bridging, TCP or UDP tunnel
transport through proxies or NAT, support for dynamic IP addresses
and DHCP, scalability to hundreds or thousands of users, and
portability to most major OS platforms.

OpenVPN is tightly bound to the OpenSSL library, and derives
much of its crypto capabilities from it.

OpenVPN supports conventional encryption using a pre-shared
secret key (Static Key mode) or public key security (SSL/TLS mode)
using client & server certificates. OpenVPN also supports
non-encrypted TCP/UDP tunnels.

OpenVPN is designed to work with the TUN/TAP virtual networking
interface that exists on most platforms.

Overall, OpenVPN aims to offer many of the key features of
IPSec but with a relatively lightweight footprint. 

#-----------------------------------------------------------------------------
%files 
%defattr(-,root,root,-)
%doc AUTHORS NEWS sample/sample-config-files
%config (noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %{_sysconfdir}/%{name}
%dir %{_var}/log/%{name}
%dir %{_var}/run/%{name}
%{_sbindir}/%{name}
%{_libdir}/%{name}/plugins/%{name}-plugin-down-root.so
%{_defaultdocdir}/%{name}-%{version}/*
%{_mandir}/man5/%{name}-examples.5.gz
%{_mandir}/man8/%{name}.8.gz

%pre
if ! getent group %{name} >/dev/null  ; then
  /usr/sbin/groupadd				\
	-K GID_MIN=50				\
	-K GID_MAX=99				\
	 %{name}

  /usr/sbin/useradd 				\
	-r					\
	-c "Privilege-separated Openvpn"	\
	-K SYS_UID_MIN=50			\
	-K SYS_UID_MAX=99			\
	-g %{name}				\
	-s /sbin/nologin			\
	-d %{_var}/privsep/%{name}		\
	%{name}
  fi

%preun
if [ "$1" = 0 ]; then
  /usr/sbin/userdel %{name}
  /usr/sbin/groupdel %{name}
  (
  /bin/echo -n "%{name}-%{version} has been fully removed on "; date
  ) > %{_var}/log/README-%{name}-removed
  fi


#=============================================================================
%package		devel

Summary		:	Development headers for '%{name}'

#-----------------------------------------------------------------------------
Requires	:       %{name} = %{version}-%{release}

#-----------------------------------------------------------------------------
%description		devel
OpenVPN can be extended through the --plugin option,
which provides possibilities to add specialized
authentication, user accounting, packet filtering and
related features.  These plug-ins need to be written
in C and provides a more low-level and information
rich access to similar features as the various script-hooks.

#-----------------------------------------------------------------------------
%files			devel
%defattr(-,root,root, -)
%{_includedir}/%{name}/*.h

#=============================================================================
%package		sysv
Summary		:       %{name} configuration file for sysV

#-----------------------------------------------------------------------------
Requires	:	chkconfig
Requires        :       lfs-bootscripts
Requires        :       %{name} = %{version}-%{release}

BuildArch	:	noarch

#-----------------------------------------------------------------------------
%description            sysv
This package allow to use openvpn on a simple sysv (sysvinit)
linux system.

#-----------------------------------------------------------------------------
Requires	:	lfs-bootscripts
Requires	:	lsb

#-----------------------------------------------------------------------------
%files                  sysv
%defattr(-, root,root,-)
%attr (0754,root,root) %{_sysconfdir}/rc.d/init.d/%{name}

#-----------------------------------------------------------------------------

%preun			sysv
if [ "$1" = 0 ]; then
  %{_sysconfdir}/rc.d/init.d/%{name} stop > /dev/null 2>&1 || :
  %{_sbindir}/chkconfig --del %{name}
  fi

%post			sysv
%{_sbindir}/chkconfig --add %{name}
if [ "$1" -ge 1 ]; then
  %{_sysconfdir}/rc.d/init.d/%{name} condrestart > /dev/null 2>&1 || :
  fi

#=============================================================================
%package		systemd
Summary		:       %{name} configuration file for systemd

#-----------------------------------------------------------------------------
Requires        :       %{name} = %{version}-%{release}

BuildArch	:	noarch
#-----------------------------------------------------------------------------
%description            systemd
This package allow to use '%{name}' on a linux systemd system.

#-----------------------------------------------------------------------------
%files                  systemd
%defattr(-, root,root,-)
%{_libdir}/systemd/system/%{name}-client@.service
%{_libdir}/systemd/system/%{name}-server@.service

#-----------------------------------------------------------------------------
%post			systemd
systemctl daemon-reload

%preun			systemd
systemctl daemon-reload

#=============================================================================
%prep
%setup -q

#-----------------------------------------------------------------------------
#building application
%build

tar xf %{SOURCE1}

autoreconf -vif
./configure						\
        --prefix=%{_prefix}				\
        --includedir=%{_includedir}/%{name}		\
	--exec-prefix=%{_exec_prefix}			\
	--libexecdir=%{_libexecdir}/%{name}		\
        --sysconfdir=%{_sysconfdir}/%{name}		\
        --sbindir=%{_sbindir}				\
	--mandir=%{_mandir}				\
	--libdir=%{_libdir}				\
	--infodir=%{_infodir}				\
	--docdir=%{_defaultdocdir}/%{name}-%{version}	\
	--disable-static				\
	--disable-systemd				\
	--disable-selinux				\
	--disable-plugin-auth-pam			\
	--enable-iproute2				\
	--with-crypto-library=openssl			\
	--enable-x509-alt-username 			\
	--enable-lz4					\
	--enable-server					\

%define _smp_mflags -j%(/usr/bin/getconf _NPROCESSORS_ONLN)
%{__make} %{_smp_mflags}

%{__make}						\
	-C distro/systemd				\
	%{name}-client@.service				\
	%{name}-server@.service	

#-----------------------------------------------------------------------------
%clean
%{__rm} -rf %{buildroot}

#-----------------------------------------------------------------------------
%check

#-----------------------------------------------------------------------------
#installing program
%install

%{__rm} -rf %{buildroot}

%{__make}						\
	DESTDIR=%{buildroot}				\
	install

#installing the systemd services
install -vDm0640					\
	distro/systemd/%{name}-client@.service		\
	distro/systemd/%{name}-server@.service		\
	-t %{buildroot}%{_libdir}/systemd/system/

#To remove libtool library
find 							\
	%{buildroot}%{_libdir}				\
	-name \*.la					\
	-delete

#installing openvpn starting/stopping script
%{__mkdir_p} %{buildroot}%{_sysconfdir}/rc.d/init.d
%{__cp} -a 						\
	%{name}-ok_addon/openvpn.init.d.ok		\
	%{buildroot}%{_sysconfdir}/rc.d/init.d/%{name}

#installing openvpn logrotate
%{__mkdir_p} %{buildroot}%{_sysconfdir}/logrotate.d
%{__cp} -a 						\
	%{name}-ok_addon/%{name}.logrotate		\
	%{buildroot}%{_sysconfdir}/logrotate.d/%{name}

%{__mkdir_p} %{buildroot}%{_sysconfdir}/%{name}
%{__mkdir_p} %{buildroot}%{_var}/log/%{name}
%{__mkdir_p} %{buildroot}%{_var}/run/%{name}

#-----------------------------------------------------------------------------
%changelog
%autochangelog
